@@ -5,13 +5,14 @@ BEGIN {
     }
 }
 use Encode;
-our $VERSION = do { my @r = (q$Revision: 0.96 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+our $VERSION = do { my @r = (q$Revision: 0.98 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 use XSLoader;
 XSLoader::load('Encode::JP',$VERSION);
 
 use Encode::JP::JIS;
 use Encode::JP::ISO_2022_JP;
+use Encode::JP::ISO_2022_JP_1;
 
 1;
 __END__
@@ -41,6 +42,9 @@ supported are as follows.
   iso-2022-jp			ISO-2022-JP 
 				(7bit JIS with all Halfwidth Kana 
 				 converted to Fullwidth)
+  iso-2022-jp-1			ISO-2022-JP-1
+                                (ISO-2022-JP with JIS X 0212-1990
+				 support. See below)
   macjapan      Mac Japan	(Shift JIS + Apple vendor mappings)
   cp932         Code Page 932	(Shift JIS + MS/IBM vendor mappings)
   --------------------------------------------------------------------
@@ -49,12 +53,34 @@ supported are as follows.
 
 To find how to use this module in detail, see L<Encode>.
 
+=head1 Note on ISO-2022-JP(-1)?
+
+ISO-2022-JP-1 (RFC2237) is a superset of ISO-2022-JP (RFC1468) which
+adds support for JIS X 0212-1990.  That means you can use the same
+code to decode to utf8 but not vice versa.
+
+  $utf8 = decode('iso-2022-jp-1', $stream);
+  $utf8 = decode('iso-2022-jp',   $stream);
+
+Yields the same result but
+
+  $with_0212 = encode('iso-2022-jp-1', $utf8);
+
+is now different from
+
+  $without_0212 = encode('iso-2022-jp', $utf8 );
+
+In the latter case, characters that map to 0212 are at first converted
+to U+3013 (0xA2AE in EUC-JP; a white square also known as 'Tofu') then
+fed to decoding engine.  U+FFFD is not used to preserve text layout as
+much as possible.
+
 =head1 BUGS
 
 ASCII part (0x00-0x7f) is preserved for all encodings, even though it
 conflicts with mappings by the Unicode Consortium.  See
 
-F<http://www.debian.or.jp/~kubota/unicode-symbols.html.en>
+L<http://www.debian.or.jp/~kubota/unicode-symbols.html.en>
 
 to find why it is implemented that way.
 
