@@ -5,7 +5,7 @@ use Encode::JP::H2Z;
 use base 'Encode::Encoding';
 
 use vars qw($VERSION);
-$VERSION = do { my @r = (q$Revision: 0.94 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 0.98 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 my $canon = 'iso-2022-jp';
 my $obj = bless {name => $canon}, __PACKAGE__;
@@ -31,7 +31,7 @@ sub encode
     my ($obj,$str,$chk) = @_;
     my $euc =  Encode::encode('euc-jp', $str, $chk);
     &Encode::JP::H2Z::h2z(\$euc);
-    return &Encode::JP::JIS::euc_jis(\$euc);
+    return &Encode::JP::JIS::euc_jis_nox0212(\$euc);
 }
 
 1;
